import { i18n } from '@/i18n'

import {
  isHardMode,
  numberOfGamesSinceStart,
  operations,
  result,
} from './game-state'
import { showToast } from './toast-manager'

function getSharingText(): string {
  const endResult = operations[operations.length - 1].result?.value ?? 0
  const success = result.value === endResult

  const allSymbols = ['🄰', '🄱', '🄲', '🄳', '🄴', '🄵', '🄶', '🄷', '🄸', '🄹']
  const squares = ['🟦', '🟩', '🟨', '🟧', '🟥']

  const lines: string[] = []
  for (const op of operations) {
    op.left!.symbol = op.left!.symbol ?? allSymbols.shift()
    op.right!.symbol = op.right!.symbol ?? allSymbols.shift()
    op.result!.symbol = op.result!.symbol ?? allSymbols.shift()

    let s = ''
    switch (op.operator) {
      case '*':
        s = '×'
        break
      case '/':
        s = '÷'
        break
      case '-':
        s = '−'
        break
      case '+':
        s = '+'
        break
    }
    lines.push(
      `${squares.shift()} ${op.left?.symbol} ${s} ${op.right?.symbol} = ${
        op.result?.value === endResult ? endResult : op.result?.symbol
      }`,
    )
  }

  return `N0mbers #${numberOfGamesSinceStart()} - ${isHardMode.value ? 'Advanced' : 'Normal'}
${lines.join('\n')} ${success ? '✔' : '❌'}
https://n0mbers.scambier.xyz`
}

export function toClipboard(): void {
  navigator.clipboard.writeText(getSharingText())
  showToast(i18n.global.t('copiedInClipboard'), 3000)
}
